# IDeSyDe

This is the generic Design Space Exploration (DSE) tool associated with the ForSyDe Ecosystem and the spiritual sucessor of [DeSyDe](https://github.com/forsyde/DeSyDe). Check the [documentation website for more information](https://forsyde.github.io/IDeSyDe/)!
